import { ColumnOptions } from "typeorm";
import { SpecialFields } from "../typings/SpecialFields";
/**
 * Decorator for special column storing encrypted data.
 *
 * @param type Column type.
 * @param options Additional options.
 * @return The decorator function.
 *
 * @author Jeongho Nam - https://github.com/samchon
 */
export declare function EncryptedColumn(type: EncryptedColumn.Type, options: EncryptedColumn.IOptions): Function;
export declare namespace EncryptedColumn {
    /**
     * Type of an encrypted column.
     */
    type Type = "varchar" | "text" | "longtext";
    /**
     * Detailed options of an encrypted column,
     */
    interface IOptions extends Omit<ColumnOptions, "type"> {
        password: IPassword | IPassword.Closure;
        index?: boolean;
    }
    /**
     * Password for the encryption.
     */
    interface IPassword {
        key: string;
        iv: string;
    }
    namespace IPassword {
        /**
         * Closure function type generating a password referencing the content.
         */
        type Closure = (content: string, isEncode: boolean) => IPassword;
    }
    /**
     * Get raw value from an encrypted column.
     *
     * @param record Target record.
     * @param field Target field.
     * @return The raw value.
     */
    function getRawValue<Entity extends object, Field extends SpecialFields<Entity, string | null>>(record: Entity, field: Field): Field extends SpecialFields<Entity, string> ? string : string | null;
    function getIndexField(key: string): string;
}
