"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EncryptedColumn = void 0;
var typeorm_1 = require("typeorm");
var AesPkcs5_1 = require("../utils/AesPkcs5");
/**
 * Decorator for special column storing encrypted data.
 *
 * @param type Column type.
 * @param options Additional options.
 * @return The decorator function.
 *
 * @author Jeongho Nam - https://github.com/samchon
 */
function EncryptedColumn(type, options) {
    return function (target, key) {
        var field = EncryptedColumn.getIndexField(key);
        (0, typeorm_1.Column)(type, __assign(__assign({}, options), { name: key }))(target, field);
        if (options.index === true)
            (0, typeorm_1.Index)()(target, field);
        Object.defineProperty(target, key, {
            get: function () {
                var content = this[field];
                if (content === null || content === undefined)
                    return null;
                else {
                    var password = options.password instanceof Function
                        ? options.password(content, false)
                        : options.password;
                    return AesPkcs5_1.AesPkcs5.decrypt(content, password.key, password.iv);
                }
            },
            set: function (content) {
                if (content === null || content === undefined) {
                    this[field] = null;
                    return;
                }
                var password = options.password instanceof Function
                    ? options.password(content, true)
                    : options.password;
                this[field] = AesPkcs5_1.AesPkcs5.encrypt(content, password.key, password.iv);
            },
        });
    };
}
exports.EncryptedColumn = EncryptedColumn;
(function (EncryptedColumn) {
    /**
     * Get raw value from an encrypted column.
     *
     * @param record Target record.
     * @param field Target field.
     * @return The raw value.
     */
    function getRawValue(record, field) {
        var hidden = getIndexField(field);
        return record[hidden];
    }
    EncryptedColumn.getRawValue = getRawValue;
    function getIndexField(key) {
        return "__m_enc_".concat(key, "__");
    }
    EncryptedColumn.getIndexField = getIndexField;
    /**
     * @internal
     */
    function getFieldByIndex(index) {
        return index.substring(8, index.length - 2);
    }
    EncryptedColumn.getFieldByIndex = getFieldByIndex;
})(EncryptedColumn = exports.EncryptedColumn || (exports.EncryptedColumn = {}));
//# sourceMappingURL=EncryptedColumn.js.map