import { Creator } from "../typings/Creator";
import { Initialized } from "../typings/Initialized";
/**
 * Initialize a model instance.
 *
 * `initailize()` is a global function creating a new model instance very safely.
 *
 * Unlike `TypeORM.Repository.create()` method, who can cause the critical runtime error by
 * ommitting essential variables, the `initialize()` function does nott permit ommitting the
 * essential member variables in the compilation level.
 *
 * In such reason, if you don't ignore error message from the TypeScript compiler, there can't be
 * any runtime error that is caused by the ommitting essential column values in the SQL INSERT or
 * UPDATE level.
 *
 * @template T Type of a model class that is derived from the `Model`
 * @param input Variables that would be assigned to the new model instance
 * @return A new model instance
 */
export declare function initialize<T extends object>(creator: Creator<T>, input: Initialized<T>): T;
